Message class

Represents a message in the response.

Constructors

Message({String? content, String? role, dynamic toolCalls, dynamic functionCall})
Message.fromJson(Map<String, dynamic> json)
Creates a Message instance from a JSON map.
factory

Properties

content String?
The content of the message
getter/setter pair
functionCall ↔ dynamic
Any function calls made during generation
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
role String?
The role of the message sender (e.g., "user", "assistant")
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
toolCalls ↔ dynamic
Any tool calls made during generation
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts this Message instance to a JSON map.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited